package sae.android.sae_2a.data

import android.provider.ContactsContract.CommonDataKinds.Website.URL
import org.json.JSONObject
import java.io.InputStream
import java.net.HttpURLConnection
import java.net.URL

class LoginResponseParser {
    fun parse(inputStream: InputStream): LoginResponse {
        val responseString = inputStream.bufferedReader().use { it.readText() }
        // Supposons que la réponse du serveur soit un JSON contenant une clé "token"
        val jsonObject = JSONObject(responseString)
        val token = jsonObject.getString("token")
        return LoginResponse(token)
    }
}

data class LoginResponse(
    val token: String
)

sealed class Result<out R> {
    data class Success<out T>(val data: T) : Result<T>()
    data class Error(val exception: Exception) : Result<Nothing>()
}
class LoginRepository(private val responseParser: LoginResponseParser) {

        private val loginUrl = "https://codefirst.iut.uca.fr/containers/antoinejourdain-api_container/Auth/token"

        // Function that makes the network request, blocking the current thread
        fun makeLoginRequest(
            jsonBody: String
        ): Result<LoginResponse> {
            val url = URL(loginUrl)
            (url.openConnection() as? HttpURLConnection)?.run {
                requestMethod = "POST"
                setRequestProperty("Content-Type", "application/json; utf-8")
                setRequestProperty("Accept", "application/json")
                doOutput = true
                outputStream.write(jsonBody.toByteArray())
                return Result.Success(responseParser.parse(inputStream))
            }
            return Result.Error(Exception("Cannot open HttpURLConnection"))
        }

    }
