package sae.android.sae_2a.view

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.layout.wrapContentHeight
import androidx.compose.foundation.layout.wrapContentWidth
import androidx.compose.material.BottomNavigation
import androidx.compose.material.BottomNavigationItem
import androidx.compose.material3.Button
import androidx.compose.material3.Icon
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Surface
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavDestination.Companion.hierarchy
import androidx.navigation.NavGraph.Companion.findStartDestination
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.currentBackStackEntryAsState
import androidx.navigation.compose.rememberNavController
import sae.android.sae_2a.R
import sae.android.sae_2a.data.Screen
import sae.android.sae_2a.game.VocabularyScreen

val items = listOf(
    Screen.Game,
    Screen.VocabularyList,
    Screen.Profile
)


@Preview
@Composable
fun MyApp() {
    val navController = rememberNavController()
    Scaffold(
        bottomBar = {
            val navBackStackEntry by navController.currentBackStackEntryAsState()
            val currentDestination = navBackStackEntry?.destination
            if (currentDestination?.route !in listOf(Screen.Home.route, Screen.Login.route , Screen.Register.route)) {
                BottomNavigation {
                    items.forEach { screen ->
                        BottomNavigationItem(
                            modifier = Modifier
                                .background(Color.Gray),
                            label = { Text(stringResource(screen.resourceId)) },
                            selected = currentDestination?.hierarchy?.any { it.route == screen.route } == true,
                            onClick = {
                                navController.navigate(screen.route) {
                                    popUpTo(navController.graph.findStartDestination().id) {
                                        saveState = true
                                    }
                                    launchSingleTop = true
                                    restoreState = true
                                }
                            },
                            icon = {
                                Icon(
                                    screen.image , contentDescription = null
                                )
                            })
                    }
                }
            }
        }
    ) { innerPadding ->
        NavHost(navController, startDestination = Screen.Home.route, Modifier.padding(innerPadding)) {
            composable(Screen.Home.route) { HomeScreen(NavigateToRegister = { navController.navigate(
                Screen.Register.route) }, NavigateToLogin = { navController.navigate(Screen.Login.route) }) }
            composable(Screen.VocabularyList.route) { VocabularyScreen(onNavigateToList = { navController.popBackStack() }) }
            composable(Screen.Register.route) { RegisterScreen(NavigateToApp = { navController.navigate(
                Screen.VocabularyList.route) }) }
            composable(Screen.Game.route){ GameScreen() {} }
            composable(Screen.Login.route){LoginScreen(onLoginClicked = { _, _ -> })}
            composable(Screen.Profile.route){profileScreen()}
        }
    }
}

@Composable
fun HomeScreen(NavigateToRegister: () -> Unit,NavigateToLogin: () -> Unit ){


    Surface(modifier = Modifier
        .wrapContentWidth(align = Alignment.CenterHorizontally)
        .wrapContentHeight(align = Alignment.CenterVertically)
        .fillMaxSize(),) {
        Column( modifier = Modifier
            .background(color = Color.Gray)
            .wrapContentWidth(align = Alignment.CenterHorizontally)){
            Image(
                    painter = painterResource(id = R.drawable.logo),
                    contentDescription = "Description de l'image",
                    modifier = Modifier
                        .wrapContentWidth(align = Alignment.CenterHorizontally)
                        .width(800.dp)
                        .padding(40.dp)
                        .size(width = 200.dp, height = 200.dp)
            )
        Text(text ="InEnglishPlease", color = Color.White, fontSize = 30.sp, fontWeight = FontWeight(1000) , modifier = Modifier
            .padding(40.dp)
            .wrapContentHeight(align = Alignment.Top)
            .wrapContentWidth(align = Alignment.CenterHorizontally)
            .align(alignment = Alignment.CenterHorizontally))

            Button( onClick = { NavigateToLogin() }, modifier = Modifier
                .padding(10.dp)
                .width(500.dp)
                .height(80.dp)
                .align(alignment = Alignment.CenterHorizontally)) {
                Text(text = stringResource(id = R.string.logIn), fontSize = 20.sp)

            }
            Button(onClick = { NavigateToRegister() },modifier = Modifier
                .width(500.dp)
                .padding(10.dp)
                .height(80.dp)
                .align(alignment = Alignment.CenterHorizontally)) {
                Text(text = stringResource(id = R.string.signIn), fontSize = 20.sp)
        }
    }
    }

}